﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Drawing.Imaging;

namespace Kresleni
{
    public enum Shapes
    {
        Ellipse, Rectangle, Line, UNDEF
    };

    public partial class Form1 : Form
    {
        public Shapes tvar { get; set; }
        private int begX, begY;
        private bool drawing = false;
        public Form1()
        {
            InitializeComponent();
            tvar = Shapes.UNDEF;
            pictureBox1.Image = new Bitmap(pictureBox1.Width, pictureBox1.Height);
        }

        private void elipsaToolStripMenuItem_Click(object sender, EventArgs e)
        {
            elipsaToolStripMenuItem.Checked = true;
            obdelnikToolStripMenuItem.Checked = false;
            caraToolStripMenuItem.Checked = false;
            tvar = Shapes.Ellipse;
            shapeLabel1.Text = "Elipsa";
        }

        private void obdelnikToolStripMenuItem_Click(object sender, EventArgs e)
        {
            elipsaToolStripMenuItem.Checked = false;
            obdelnikToolStripMenuItem.Checked = true;
            caraToolStripMenuItem.Checked = false;
            tvar = Shapes.Rectangle;
            shapeLabel1.Text = "Obdélník";
        }

        private void caraToolStripMenuItem_Click(object sender, EventArgs e)
        {
            elipsaToolStripMenuItem.Checked = false;
            obdelnikToolStripMenuItem.Checked = false;
            caraToolStripMenuItem.Checked = true;
            tvar = Shapes.Line;
            shapeLabel1.Text = "Čára";
        }

        private void novýToolStripMenuItem_Click(object sender, EventArgs e)
        {
            pictureBox1.Image = new Bitmap(pictureBox1.Width, pictureBox1.Height);
            pictureBox1.BackColor = Color.White;
            pictureBox1.Refresh();
        }

        private void konecToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void pictureBox1_MouseDown(object sender, MouseEventArgs e)
        {
            if (tvar == Shapes.UNDEF)
            {
                MessageBox.Show("Nejprve je nutné si vybrat, co chcete kreslit.","Chyba!");
                return;
            }
            begX = e.X;
            begY = e.Y;
            drawing = true;
        }

        private void pictureBox1_MouseUp(object sender, MouseEventArgs e)
        {
            int bX,dX,bY,dY;
            if(tvar!=Shapes.UNDEF && drawing )
            
            using(Graphics g = Graphics.FromImage(pictureBox1.Image))
            {
                switch(tvar)
                {
                    case Shapes.Ellipse:
                        g.DrawEllipse(Pens.Black, begX, begY, e.X - begX, e.Y - begY);
                        break;
                    case Shapes.Rectangle:
                        bX= (begX < e.X?begX:e.X);
                        dX = Math.Abs(begX - e.X);
                        bY = (begY < e.Y ? begY : e.Y);
                        dY = Math.Abs(begY - e.Y);
                        g.DrawRectangle(Pens.Black, bX, bY, dX, dY);
                        break;
                    case Shapes.Line:
                        g.DrawLine(Pens.Black, begX, begY, e.X, e.Y);
                        break;
                }
            }
            drawing = false;
            pictureBox1.Refresh();
        }

        private void pictureBox1_MouseMove(object sender, MouseEventArgs e)
        {
            int bX, bY,dX,dY;
            if (tvar ==Shapes.UNDEF || !drawing) 
            {
                return;
            }
            using (Graphics g = pictureBox1.CreateGraphics())
            {
                pictureBox1.Refresh();
                switch (tvar)
                {
                    case Shapes.Ellipse:
                        g.DrawEllipse(Pens.Black, begX, begY, e.X - begX, e.Y - begY);
                        break;
                    case Shapes.Rectangle:
                        bX = (begX < e.X ? begX : e.X);
                        dX = Math.Abs(begX - e.X);
                        bY = (begY < e.Y ? begY : e.Y);
                        dY = Math.Abs(begY - e.Y);
                        g.DrawRectangle(Pens.Black, bX, bY, dX, dY);
                        break;
                    case Shapes.Line:
                        g.DrawLine(Pens.Black, begX, begY, e.X, e.Y);
                        break;
                }
            }
            
        }

        private void otevřítToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                loadFromFile(openFileDialog1.FileName);
            }
        }

        private void loadFromFile(string fileName)
        {
            pictureBox1.Image = new Bitmap(fileName);
        }

        private void uložitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                saveToFile(saveFileDialog1.FileName);
            }
        }

        private void saveToFile(string fileName)
        {
            pictureBox1.Image.Save(fileName, ImageFormat.Png);
        }
    }
}
